<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin képnézegető</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Verzió:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>kép</translation>
    </message>
    <message>
        <source>images</source>
        <translation>képek</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albumok</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Szinkronizáció kezelés</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Szinkronizáció:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Utolsó importálás</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kedvencek</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Biztosan töröljük ezt az albumot?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kedvencek</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Idővonal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>A szinkronizáláshoz felvehetünk mappát vagy húzzuk és dobjuk ide a képet az idővonalra</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Képnézegető</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Képek</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Biztos hozzáadjuk a képeket az albumhoz?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Szinkronizálás és létrehozás</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Szinkronizálás</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Biztos hozzáadjuk a szinkronizálási listához és létrehozunk egy ilyen nevű mappát?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportálás sikeresen befejeződött</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Hiba lépett fel az exportálás során</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Biztos áthelyezzük a képeket a Kukába?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Képinformáció</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ez a fájl több oldalt tartalmaz, kérlek használd az Evince-t az összes oldal megtekintéséhez.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eltávolítás az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás jobbra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás az óramutató járásával ellentétes irányba</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérnek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Képinformáció</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Felvehetjük a szinkronizált mappába vagy fogjuk és dobjuk az idővonalra</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás az albumhoz</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Hozzáadás új albumhoz</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Mappa megnyitás</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nincs engedély a kép megtekintéséhez</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Módosítás dátuma</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Fájlméret</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Színtér</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exponálás mód</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exponálás program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exponálási idő</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Vaku</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Nyílás</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fókusztávolság</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximum nyílás</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mérésmód</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Fehér egyensúly</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Vaku viszonzás</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kamera minta</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lencse minta</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Nincs igazítás</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Oldal igazítása képhez</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Kép igazítása oldalhoz</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Méretezés:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milliméter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centiméter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inch</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Kép pozíció</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Igazítás</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Kép beállításai</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Árnyékolók</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Kapcsoló</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Csúszó</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Gyönyörű</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Mappa kiválasztás</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>A mappa szinkronizálás tíltva van</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Új mappa</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Mappaszinkronizáló kezelés</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>A mappalista üres</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Szinkronizálás megszakítás</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Képek</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Az eszköz törlésre került</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ez a mappa nem létezik többé</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Kiszámítás...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Kép megtekintés</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Megtekintés vége</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Törlés az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás jobbra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás balra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképnek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Előző képernyő</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Következő képernyő</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megtekintése</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Adjunk meg új gyorsbillentyűt</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Kép megtekintése</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Alapértékek visszaállítása</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavetítés vége</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Törlés az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás jobbra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás balra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképnek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Képinformáció</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Megtekintés vége</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Megállítás/Elindítás</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavetítés beállítások</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Hatás kiválasztás</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Időtartam kiválasztás</translation>
    </message>
    <message>
        <source>second</source>
        <translation>másodperc</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Képkezelő</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Eredeti méret</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ablakhoz igazítás</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Balra forgatás</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Jobbra forgatás</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nem találhatók képek</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 kép</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 kép</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Szinkronizálási beállítások</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Szinkronizálás:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Felvehető szinkronmappának vagy húzzuk és dobjuk ide az idővonalra</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás az albumhoz</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Hozzáadás új albumhoz</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Másolás vágólapra</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás jobbra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás balra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképnek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megnyitás fájlkezelővel</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kép információ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavetítés beállítások</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Hatás</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>yyyy MMMM dd</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kedvenceim</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Utolsó importálás</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Új album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>A Deepin Image Viewer egy egyszerű, de korszerű képkezelő.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Képnézegető alkalmazás pár alap képszerkesztési funkcióval.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Sötét téma</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Idővonal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Hozzáadás albumhoz</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Hozzáadás új albumhoz</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Kilépés a teljes képernyőből</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavetítés</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Nyomtatás</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Másolás</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Törlés az albumból</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nem kedvenc</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigációs ablak megjelenítése</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigációs ablak elrejtése</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Forgatás jobbra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Forgatás balra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Beállítás háttérképnek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megtekintés fájlkezelőben</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Képinformáció</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>